#version 330

layout (location = 0) in vec3 vPosition;
layout (location = 1) in vec3 vNormal;
layout (location = 2) in vec2 vTexCoord;

/*Values set by the renderer*/
uniform mat4 modelViewProjectionMatrix;
uniform mat4 prevMVPMatrix;
uniform mat3 normalMatrix;

uniform mat4 DepthBiasMVP;


/*Values for basic lightning*/
uniform vec3 lightDirection;
uniform vec3 lightIntensity;
uniform vec3 ambient;

out vec3 intensity;
out vec2 texCoord;
out vec4 ShadowCoord;
out vec4 position;
out vec4 prevPosition;


//Calculates the light intensity
vec3 calcIntensity() {

//Calculating the color of the pixel
	vec3 N = normalize(normalMatrix * vNormal);	
	//Calculating the diffuse factor using the dot product of the normal and the lightdirection
	float diffuseFactor = max( dot(N, lightDirection), 0.0f);
	if(diffuseFactor < 0.2) {
		diffuseFactor = 0.2;
	}
	return lightIntensity *  diffuseFactor;
}


void main() {
	position = modelViewProjectionMatrix * vec4(vPosition, 1);
	prevPosition = prevMVPMatrix * vec4(vPosition, 1);
	
	gl_Position = position;
		
	ShadowCoord = DepthBiasMVP * vec4(vPosition,1);

	intensity = calcIntensity();
	texCoord = vTexCoord;
}


