#version 330

layout (location = 0) in vec3 velocity;
layout (location = 1) in float startTime;

uniform mat4 modelViewProjectionMatrix;
uniform mat4 prevMVPMatrix;
uniform float systemTime;
uniform float factor; // Determing the intensity of the system

const float lifetime = 2.5;

out float opacity;
out vec4 position;
out vec4 prevPosition;

void main() {
	//Calculating the delta time
	float deltaT = systemTime - startTime;

	//Create time loop for continious emission
	//Each particle will reset after 3 seconds
	deltaT = mod( deltaT, lifetime);	
	//Fade particle to invisible over 3 seconds
	opacity = 1.0 - ( deltaT /lifetime);	
	
	//simulate gravity
	vec3 gravity = vec3(0.0, -1.0, 0.0);		
	vec3 pos =  velocity * factor * deltaT + gravity * deltaT * deltaT;		

	//Transform particle position into view space
	position = modelViewProjectionMatrix * vec4(pos, 1);
	prevPosition = prevMVPMatrix * vec4(pos, 1);
	gl_Position = position;
	
	//size of the particle in pixel
	gl_PointSize = 2.5;
	
}
